#version 3.8;
global_settings {assumed_gamma 1.0} 


// Use this to select which code example to run.
#declare Keyword = "atan2";




//	This work is licensed under the Creative Commons Attribution-ShareAlike 3.0 Unported License.
//	To view a copy of this license, visit http://creativecommons.org/licenses/by-sa/3.0/ or send a
//	letter to Creative Commons, 444 Castro Street, Suite 900, Mountain View, California, 94041, USA.

//	Persistence of Vision Ray Tracer version 3.8 Include File
//	File: KeywordExamples.pov
//	Last updated: 2021.3.7
//	Description: Code examples for all of the keywords in SDL
	
//-------10--------20--------30--------40--------40--------50--------60--------70--------80--------100

/*
	Development notes:
	
	Until all of the keywords have at least a basic functional example,
	I propose each edited version use a filename KeywordExamples_Dev_M_m_p_Author.pov
	This consistent with clipka's admonition that Semantic Versioning be used to track changes.
	https://semver.org/
	Given a version number MAJOR.MINOR.PATCH, increment the:
	MAJOR version when you make incompatible API changes,
	MINOR version when you add functionality in a backwards compatible manner, and
	PATCH version when you make backwards compatible bug fixes.
	
	Then the latest file can be named:
	KeywordExamples_M_m_p.pov
	
	A companion file, to hold anything which might unnecessarily clutter this file
	will be invoked using #include "KeywordExamples.inc"
		(Not sure if KeywordExamples.inc should just have one line: #include "KeywordExamples_M_m_p.inc"
		or we should just use a matching #include "KeywordExamples_M_m_p.inc" in this file)
		Use the include file for:
			pigments
			color_maps
			textures
			functions
			macros
			scene setup for rendering: such as camera and other extensive code
	
	I suggest that helpful suggestions and comments for further editing be appended to a file called
	KeywordExamples.txt
	
	And all files in this project be put into a KeywordExamples_M_m_p.zip
*/

//-------10--------20--------30--------40--------40--------50--------60--------70--------80--------100



#if (file_exists ("KeywordExamples.inc"))
	#include "KeywordExamples.inc"
#end

// Keywords Reference
// http://wiki.povray.org/content/Reference:Keywords
// POV-Ray has a number of reserved keywords which are listed below.


// #####################################################################################################
#declare Ambiguous = "Ambiguous keyword: more than one usage instance occurs in SDL! \n";
#declare NE = "Stopping render of objectless scene.  No code example for this keyword yet. \n"
#declare NO = "Stopping render of objectless scene.  Check #debug stream in console output. \n"
// #####################################################################################################



// ################################################# A #################################################

#declare this_keyword = "aa_level";
#if (Keyword = this_keyword)  
	// Code example for keyword: aa_level 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	aa_level 
#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "aa_threshold";
#if (Keyword = this_keyword)  
	// Code example for keyword: aa_threshold 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	aa_threshold 
#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "abs";
#if (Keyword = this_keyword)  
	// Code example for keyword: abs 
	/*
	Absolute value of N. If N is negative, returns -N otherwise returns N.
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#for (N, -1, 1, 0.1)
		#local N = min(max(N, -1), 1);	// clamp N = -/+1
		#local _result = abs (N);
		#debug concat ("abs (", str (N, 5, 2), ") = ", str (_result, 0, 4), " \n")
	#end
	#error NO	// Stop render
	/*
	#local abs = function (N) {select (N, -N, 0, N)}
	#local abs = function (N) {((N<0) ? (-N) : (N))}
	*/
#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "absorption";
#if (Keyword = this_keyword)  
	// Code example for keyword: absorption 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
		absorption
	/* 
	*/
	// Code example for keyword: absorption 
	 
#end 

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "accuracy";
#if (Keyword = this_keyword)  
	// Code example for keyword: accuracy 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
		keyword
	/* 
	*/
	accuracy 
#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "acos";
#if (Keyword = this_keyword)  
	// Code example for keyword: acos 
	// Version 0.1
	// Author: Bald Eagle
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	Returns the angle, expressed in radians, whose cosine is N.
	For real input to acos (N), N should be in the range -1 to +1.
	For real input, the output range of ACOS is between 0 and π.
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#local Acos = function (_N) {acos (_N)}
	#for (N, -1, 1, 0.1)
		#local N = min(max(N, -1), 1);	// clamp N = -/+1
		#debug concat ("acos (", str (N, 5, 2), ") = ", str (Acos(N), 0, 4), " radians \n")
	#end
	//#error NO	// Stop render
	
	OrthoScene (y*pi/2, P_White, 130)
	GraphLinearEquation (Acos, -1, 1, 0, pi, pi/90, 0.01)

	/*
	Coding syntax notes:
	Passing values outside of -1 to +1 to acos will result in an error:
	Parse Warning: Domain error in acos.
	So you may want to sanity check / limit your input as follows:
	#local N = min(max(N, -1), 1);
	#local N = max(min(N, 1), -1);
	#local N = (N < -1) ? -1 : ((N > 1) ? 1 : N)
	*/
#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "acosh";
#if (Keyword = this_keyword)  
	// Code example for keyword: acosh 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	https://franz.com/support/documentation/ansicl.94/dictentr/sinhcosh.htm
	The following definition for the inverse hyperbolic cosine determines the range and branch cuts:
	arccosh z = 2 log (sqrt((z+1) /2) + sqrt((z-1)/2)).
	The branch cut for the inverse hyperbolic cosine function lies along the real axis 
	to the left of 1 (inclusive), extending indefinitely along the negative real axis, 
	continuous with quadrant II and (between 0 and 1) with quadrant I. 
	The range is that half-strip of the complex plane containing numbers whose real part 
	is non-negative and whose imaginary part is between - pi (exclusive) and  pi (inclusive). 
	A number with real part zero is in the range if its imaginary part is between zero (inclusive) 
	and  pi (inclusive).
	The result of acosh may be a complex even if number is not a complex; this occurs when number is 
	less than one. Also, the result of atanh may be a complex even if number is not a complex; 
	this occurs when the absolute value of number is greater than one.
	https://www.mathworks.com/help/matlab/ref/acosh.html
	acosh(x)=log(x+sqrt(pow(x,2)−1))

	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#local Acosh = function (_N) {acosh (_N)}
	#for (N, 0, tau, 0.1)
		#debug concat ("acosh (", str (N, 5, 2), ") = ", str (Acosh(N), 0, 4), " radians \n")
	#end
	//#error NO	// Stop render
	
	OrthoScene (<3, 1.25, 0>, P_White, 100)
	GraphLinearEquation (Acosh, 0, tau, 0, 2.5, tau/90, 0.01)
	/* 
	*/

#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "adaptive";
#if (Keyword = this_keyword)  
	// Code example for keyword: adaptive 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
		keyword
	/* 
	*/

	adaptive 
#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "adc_bailout";
#if (Keyword = this_keyword) 
	#warning Ambiguous
	#warning "Please specify: \n"
	#warning "adc_bailout global setting \n"
	#warning " - or - \n"
	#warning "adc_bailout radiosity \n"
	#error NO
#end

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "adc_bailout global setting";
#if (Keyword = this_keyword) 
	// Code example for keyword: adc_bailout global setting
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
		keyword
	/* 
	*/ 
	// Code example for keyword: adc_bailout global setting 
	adc_bailout global setting 
#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "adc_bailout radiosity";
#if (Keyword = this_keyword)  
	// Code example for keyword: adc_bailout 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
		keyword
	/* 
	*/
	// Code example for keyword: adc_bailout radiosity 
	adc_bailout radiosity 
#end 


// -----------------------------------------------------------------------------------------------------
/*
#if (Keyword = this_keyword)  // Code example for keyword: agate agate #end  
// -----------------------------------------------------------------------------------------------------

#if (Keyword = this_keyword)  // Code example for keyword: agate_turb agate_turb #end  
// -----------------------------------------------------------------------------------------------------

#if (Keyword = this_keyword)  // Code example for keyword: albedo diffuse albedo diffuse #end  
// -----------------------------------------------------------------------------------------------------

#if (Keyword = this_keyword)  // Code example for keyword: albedo phong albedo phong #end  
// -----------------------------------------------------------------------------------------------------

#if (Keyword = this_keyword)  // Code example for keyword: albedo specular albedo specular #end  
// -----------------------------------------------------------------------------------------------------

#if (Keyword = this_keyword)  // Code example for keyword: all all #end  
// -----------------------------------------------------------------------------------------------------

#if (Keyword = this_keyword)  // Code example for keyword: all_intersections all_intersections #end  
// -----------------------------------------------------------------------------------------------------

#if (Keyword = this_keyword)  // Code example for keyword: alpha alpha #end 
// -----------------------------------------------------------------------------------------------------
 
#if (Keyword = this_keyword)  // Code example for keyword: altitude altitude #end  
// -----------------------------------------------------------------------------------------------------

#if (Keyword = this_keyword)  // Code example for keyword: always_sample always_sample #end 
// -----------------------------------------------------------------------------------------------------
 
#if (Keyword = this_keyword)  // Code example for keyword: ambient ambient #end 
// -----------------------------------------------------------------------------------------------------
 
#if (Keyword = this_keyword)  // Code example for keyword: ambient_light ambient_light #end  
// -----------------------------------------------------------------------------------------------------

#if (Keyword = this_keyword)  // Code example for keyword: angle angle #end 
// -----------------------------------------------------------------------------------------------------
 
#if (Keyword = this_keyword)  // Code example for keyword: aoi aoi #end  
// -----------------------------------------------------------------------------------------------------

#if (Keyword = this_keyword)  // Code example for keyword: aperture aperture #end  
// -----------------------------------------------------------------------------------------------------

#if (Keyword = this_keyword)  // Code example for keyword: append append #end  
// -----------------------------------------------------------------------------------------------------

#if (Keyword = this_keyword)  // Code example for keyword: arc_angle arc_angle #end  
// -----------------------------------------------------------------------------------------------------

#if (Keyword = this_keyword)  // Code example for keyword: area_illumination area_illumination #end  
// -----------------------------------------------------------------------------------------------------

#if (Keyword = this_keyword)  // Code example for keyword: area_light area_light #end  
// -----------------------------------------------------------------------------------------------------

#if (Keyword = this_keyword)  // Code example for keyword: array array #end  
*/
// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "asc";
#if (Keyword = this_keyword)  
	// Code example for keyword: asc 
	// Version 0.1
	// Author: Bald Eagle
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#for (N, 32, 126)
		#local Glyph = chr(N);			// generate a 1-character long string from the loop variable
		#local AsciiVal = asc (Glyph);	// Determine the ASCII value of the character
		#debug concat ("The ASCII value for ", chr(34), Glyph, chr(34), " is ", str (AsciiVal, 0, 0), " \n")
	#end
	#error NO	// Stop render
	/*
	Also see: chr (N)
	*/
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "ascii";
#if (Keyword = this_keyword)  
	// Code example for keyword: ascii  
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
		ascii
	/* 
	*/

ascii 
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "asin";
#if (Keyword = this_keyword)  
	// Code example for keyword: asin 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	For real values of X in the interval [-1, 1], asin(X) returns values in the interval [-π/2, π/2].
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#local Asin = function (_N) {asin (_N)}
	#for (N, -1, 1, 0.1)
		#debug concat ("asin (", str (N, 5, 2), ") = ", str (Asin(N), 0, 4), " radians \n")
	#end
	//#error NO	// Stop render
	
	OrthoScene (0, P_White, 130)
	GraphLinearEquation (Asin, -1, 1, -pi/2, pi/2, pi/360, 0.01)
	/* 
	*/
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "asinh";
#if (Keyword = this_keyword)  
	// Code example for keyword: asinh
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	https://franz.com/support/documentation/ansicl.94/dictentr/sinhcosh.htm
	The following definition for the inverse hyperbolic sine determines the range and branch cuts:
	arcsinh z = log (z+sqrt(1+z2)).
	The branch cut for the inverse hyperbolic sine function is in two pieces: one along the positive 
	imaginary axis above i (inclusive), continuous with quadrant I, and one along the negative 
	imaginary axis below -i (inclusive), continuous with quadrant III. The range is that strip of 
	the complex plane containing numbers whose imaginary part is between - pi /2 and  pi /2. 
	A number with imaginary part equal to - pi /2 is in the range if and only if its real part 
	is non-positive; a number with imaginary part equal to pi /2 is in the range if and only if its 
	imaginary part is non-negative.
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#local Asinh = function (_N) {asinh (_N)}
	#for (N, -tau, tau, tau/10)
		#debug concat ("asinh (", str (N, 5, 2), ") = ", str (Asinh(N), 0, 4), " radians \n")
	#end
	//#error NO	// Stop render
	
	OrthoScene (0, P_White, 100)
	GraphLinearEquation (Asinh, -tau, tau, -2.5, 2.5, tau/360, 0.01)
	/* 
	*/
#end 

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "assumed_gamma";
#if (Keyword = this_keyword)  
	// Code example for keyword: assumed_gamma 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
		keyword
	/* 
	*/
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "atan";
#if (Keyword = this_keyword)  
	// Code example for keyword: atan 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
		keyword
	/* 
	*/
#end 

// -----------------------------------------------------------------------------------------------------
 
#declare this_keyword = "atan2";
#if (Keyword = this_keyword) 
	// Code example for keyword: atan2
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	atan2 (y, x) returns the four-quadrant inverse tangent (tan-1) of Y and X
	The four-quadrant inverse tangent, atan2(Y,X), returns values in the closed interval [-pi,pi] 
	based on the values of Y and X.
	(In contrast, atan(Y/X) returns results that are limited to the interval [-pi/2,pi/2])
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#local Line = 0.01;
	sphere {0 Line*2 texture {T_Wht}}
	torus {1 Line texture {T_Blu} rotate x*90}
	#macro PlotAtan2 (X, Y, Line)
		#local _Vector = <X, Y, 0>;
		sphere {_Vector Line*3 texture {T_Grn}}
		cylinder {0, _Vector Line texture {T_Blk} no_shadow}
		#local _Angle = atan2 (Y, X);
		#local _Angled = _Angle * 180/pi;
		cylinder {0, x*0.9 Line*1.5 rotate z*_Angled texture {T_Red} no_shadow}
		cone {x*0.9, Line*4.5, x, 0 rotate z*_Angled texture {T_Red} no_shadow}
	#end // end macro PlotAtan2 
	OrthoScene (0, P_Gray, 100)
	#for (Y, -2, 2, 4)
		#for (X, -2, 2, 0.5)
			PlotAtan2 (X, Y, Line)
		#end // end for X
	#end // end for Y
	#for (X, -2, 2, 4)
		#for (Y, -2, 2, 0.5)
			PlotAtan2 (X, Y, Line)
		#end // end for X
	#end // end for Y
	/* 
	atan2 is an extremely useful function when you need to calculate the angle of a 
	point or vector.
	*/ 
#end 

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "atand";
#if (Keyword = this_keyword)  
	// Code example for keyword: atand 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	atand
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
		keyword
	/* 
	*/
#end 

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "atanh";
#if (Keyword = this_keyword)  
	// Code example for keyword: atanh
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	https://franz.com/support/documentation/ansicl.94/dictentr/sinhcosh.htm
	The following definition for the inverse hyperbolic tangent determines the range and branch cuts:
	arctanh z = (log (1+z) - log (1-z))/2.
	Note that:
	i arctan z = arctanh iz.
	The branch cut for the inverse hyperbolic tangent function is in two pieces: one along the 
	negative real axis to the left of -1 (inclusive), continuous with quadrant III, and one along the 
	positive real axis to the right of 1 (inclusive), continuous with quadrant I. The points -1 and 1 are 
	excluded from the domain. The range is that strip of the complex plane containing numbers whose 
	imaginary part is between - pi /2 and pi /2. A number with imaginary part equal to - pi /2 is in 
	the range if and only if its real part is strictly negative; a number with imaginary part equal to 
	pi /2 is in the range if and only if its imaginary part is strictly positive. Thus the range of the 
	inverse hyperbolic tangent function is identical to that of the inverse hyperbolic sine function 
	with the points - pi i/2 and  pi i/2 excluded.
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
		keyword
	/* 
	*/
#end 

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "autostop";
#if (Keyword = this_keyword)  
	// Code example for keyword: autostop  
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
		keyword
	/* 
	*/
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "average";
#if (Keyword = this_keyword) 
	// Code example for keyword: average
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
		keyword
	/* 
	*/ 
#end  

// ################################################# B #################################################
/*
#if (Keyword = this_keyword)  // Code example for keyword: b_spline b_spline #end  
#if (Keyword = this_keyword)  // Code example for keyword: background background #end  
#if (Keyword = this_keyword)  // Code example for keyword: bezier_spline bezier_spline #end  
#if (Keyword = this_keyword)  // Code example for keyword: bicubic_patch bicubic_patch #end  
#if (Keyword = this_keyword)  // Code example for keyword: bitwise_and bitwise_and #end  
#if (Keyword = this_keyword)  // Code example for keyword: bitwise_or bitwise_or #end  
#if (Keyword = this_keyword)  // Code example for keyword: bitwise_xor bitwise_xor #end  
#if (Keyword = this_keyword)  // Code example for keyword: black_hole black_hole #end  
#if (Keyword = this_keyword)  // Code example for keyword: blend_gamma color map blend_gamma color map #end  
#if (Keyword = this_keyword)  // Code example for keyword: blend_gamma pigment map blend_gamma pigment map #end  
#if (Keyword = this_keyword)  // Code example for keyword: blend_mode color map blend_mode color map #end  
#if (Keyword = this_keyword)  // Code example for keyword: blend_mode pigment map blend_mode pigment map #end  
#if (Keyword = this_keyword)  // Code example for keyword: blob blob #end  
#if (Keyword = this_keyword)  // Code example for keyword: blue blue #end  
#if (Keyword = this_keyword)  // Code example for keyword: blur_samples blur_samples #end  
#if (Keyword = this_keyword)  // Code example for keyword: bokeh bokeh #end  
#if (Keyword = this_keyword)  // Code example for keyword: bounded_by bounded_by #end  
#if (Keyword = this_keyword)  // Code example for keyword: box box #end  
#if (Keyword = this_keyword)  // Code example for keyword: boxed boxed #end  
#if (Keyword = this_keyword)  // Code example for keyword: bozo bozo #end  
#if (Keyword = this_keyword)  // Code example for keyword: break break #end  
#if (Keyword = this_keyword)  // Code example for keyword: brick brick #end  
#if (Keyword = this_keyword)  // Code example for keyword: brick_size brick_size #end  
#if (Keyword = this_keyword)  // Code example for keyword: brightness brightness #end  
#if (Keyword = this_keyword)  // Code example for keyword: brilliance brilliance #end  
#if (Keyword = this_keyword)  // Code example for keyword: bump_map bump_map #end  
#if (Keyword = this_keyword)  // Code example for keyword: bump_size bump_size #end  
#if (Keyword = this_keyword)  // Code example for keyword: bumps bumps #end  
#if (Keyword = this_keyword)  // Code example for keyword: bt709 bump map bt709 bump map #end  
#if (Keyword = this_keyword)  // Code example for keyword: bt709 height field bt709 height field #end  
#if (Keyword = this_keyword)  // Code example for keyword: bt709 image map bt709 image map #end  
#if (Keyword = this_keyword)  // Code example for keyword: bt709 image pattern bt709 image pattern #end  
#if (Keyword = this_keyword)  // Code example for keyword: bt2020 bump map bt2020 bump map #end  
#if (Keyword = this_keyword)  // Code example for keyword: bt2020 height field bt2020 height field #end  
#if (Keyword = this_keyword)  // Code example for keyword: bt2020 image map bt2020 image map #end  
#if (Keyword = this_keyword)  // Code example for keyword: bt2020 image pattern bt2020 image pattern #end  

// ################################################# C #################################################

#if (Keyword = this_keyword)  // Code example for keyword: camera camera #end  
#if (Keyword = this_keyword)  // Code example for keyword: case case #end  
#if (Keyword = this_keyword)  // Code example for keyword: caustics caustics #end  
#if (Keyword = this_keyword)  // Code example for keyword: ceil ceil #end  
#if (Keyword = this_keyword)  // Code example for keyword: cells cells #end  
#if (Keyword = this_keyword)  // Code example for keyword: charset charset #end  
#if (Keyword = this_keyword)  // Code example for keyword: checker checker #end  
#if (Keyword = this_keyword)  // Code example for keyword: chr chr #end  
#if (Keyword = this_keyword)  // Code example for keyword: circular circular #end  
#if (Keyword = this_keyword)  // Code example for keyword: clipped_by clipped_by #end  
#if (Keyword = this_keyword)  // Code example for keyword: clock clock #end  
#if (Keyword = this_keyword)  // Code example for keyword: clock_delta clock_delta #end  
#if (Keyword = this_keyword)  // Code example for keyword: clock_on clock_on #end  
#if (Keyword = this_keyword)  // Code example for keyword: collect collect #end  
#if (Keyword = this_keyword)  // Code example for keyword: color color #end  
#if (Keyword = this_keyword)  // Code example for keyword: color_map color_map #end  
#if (Keyword = this_keyword)  // Code example for keyword: colour colour #end  
#if (Keyword = this_keyword)  // Code example for keyword: colour_map colour_map #end  
#if (Keyword = this_keyword)  // Code example for keyword: component component #end  
#if (Keyword = this_keyword)  // Code example for keyword: composite composite #end  
#if (Keyword = this_keyword)  // Code example for keyword: concat concat #end  
#if (Keyword = this_keyword)  // Code example for keyword: cone cone #end  
#if (Keyword = this_keyword)  // Code example for keyword: confidence confidence #end  
#if (Keyword = this_keyword)  // Code example for keyword: conic_sweep conic_sweep #end  
#if (Keyword = this_keyword)  // Code example for keyword: conserve_energy conserve_energy #end  
#if (Keyword = this_keyword)  // Code example for keyword: contained_by contained_by #end  
#if (Keyword = this_keyword)  // Code example for keyword: control0 control0 #end  
#if (Keyword = this_keyword)  // Code example for keyword: control1 control1 #end  
#if (Keyword = this_keyword)  // Code example for keyword: coords coords #end  
#if (Keyword = this_keyword)  // Code example for keyword: cos cos #end  
#if (Keyword = this_keyword)  
// Code example for keyword: cosh 
https://en.wikipedia.org/wiki/Catenary#Equation
cosh 
#end  
#if (Keyword = this_keyword)  // Code example for keyword: count count #end  
#if (Keyword = this_keyword)  // Code example for keyword: crackle crackle #end  
#if (Keyword = this_keyword)  // Code example for keyword: crand crand #end  
#if (Keyword = this_keyword)  // Code example for keyword: cube cube #end  
#if (Keyword = this_keyword)  // Code example for keyword: cubic object cubic object #end  
#if (Keyword = this_keyword)  // Code example for keyword: cubic pattern cubic pattern #end  
#if (Keyword = this_keyword)  // Code example for keyword: cubic warp cubic warp #end  
#if (Keyword = this_keyword)  // Code example for keyword: cubic_spline cubic_spline #end  
#if (Keyword = this_keyword)  // Code example for keyword: cubic_wave cubic_wave #end  
#if (Keyword = this_keyword)  // Code example for keyword: cutaway_textures cutaway_textures #end  
#if (Keyword = this_keyword)  // Code example for keyword: cylinder cylinder #end  
#if (Keyword = this_keyword)  // Code example for keyword: cylindrical cylindrical #end  

// ################################################# D #################################################

#if (Keyword = this_keyword)  // Code example for keyword: datetime datetime #end  
#if (Keyword = this_keyword)  // Code example for keyword: debug debug #end  
#if (Keyword = this_keyword)  // Code example for keyword: declare declare #end  
#if (Keyword = this_keyword)  // Code example for keyword: default default #end  
#if (Keyword = this_keyword)  // Code example for keyword: defined defined #end  
#if (Keyword = this_keyword)  // Code example for keyword: degrees degrees #end  
#if (Keyword = this_keyword)  // Code example for keyword: density density #end  
#if (Keyword = this_keyword)  // Code example for keyword: density_file density_file #end  
#if (Keyword = this_keyword)  // Code example for keyword: density_map density_map #end  
#if (Keyword = this_keyword)  // Code example for keyword: dents dents #end  
#if (Keyword = this_keyword)  // Code example for keyword: deprecated deprecated #end  
#if (Keyword = this_keyword)  // Code example for keyword: df3 df3 #end  
#if (Keyword = this_keyword)  // Code example for keyword: dictionary dictionary #end  
#if (Keyword = this_keyword)  // Code example for keyword: difference csg difference csg #end  
#if (Keyword = this_keyword)  // Code example for keyword: difference torus difference torus #end  
#if (Keyword = this_keyword)  // Code example for keyword: diffuse diffuse #end  
#if (Keyword = this_keyword)  // Code example for keyword: dimension_size dimension_size #end  
#if (Keyword = this_keyword)  // Code example for keyword: dimensions dimensions #end  
#if (Keyword = this_keyword)  // Code example for keyword: direction direction #end  
#if (Keyword = this_keyword)  // Code example for keyword: disc disc #end  
#if (Keyword = this_keyword)  // Code example for keyword: dispersion dispersion #end  
#if (Keyword = this_keyword)  // Code example for keyword: dispersion_samples dispersion_samples #end  
#if (Keyword = this_keyword)  // Code example for keyword: dist_exp dist_exp #end  
#if (Keyword = this_keyword)  // Code example for keyword: distance fog distance fog #end  
#if (Keyword = this_keyword)  // Code example for keyword: distance ovus distance ovus #end  
#if (Keyword = this_keyword)  // Code example for keyword: div div #end  
#if (Keyword = this_keyword)  // Code example for keyword: double_illuminate double_illuminate #end  

// ################################################# E #################################################

#if (Keyword = this_keyword)  // Code example for keyword: eccentricity eccentricity #end  
#if (Keyword = this_keyword)  // Code example for keyword: else else #end  
#if (Keyword = this_keyword)  // Code example for keyword: elseif elseif #end  
#if (Keyword = this_keyword)  // Code example for keyword: emission finish emission finish #end  
#if (Keyword = this_keyword)  // Code example for keyword: emission media emission media #end  
#if (Keyword = this_keyword)  // Code example for keyword: end end #end  
#if (Keyword = this_keyword)  // Code example for keyword: error error #end  
#if (Keyword = this_keyword)  // Code example for keyword: error_bound error_bound #end  
#if (Keyword = this_keyword)  // Code example for keyword: evaluate evaluate #end  
#if (Keyword = this_keyword)  // Code example for keyword: exp exp #end  
#if (Keyword = this_keyword)  // Code example for keyword: expand_thresholds expand_thresholds #end  
#if (Keyword = this_keyword)  // Code example for keyword: exponent exponent #end  
#if (Keyword = this_keyword)  // Code example for keyword: exterior exterior #end  
#if (Keyword = this_keyword)  // Code example for keyword: extinction extinction #end  

// ################################################# F #################################################

#if (Keyword = this_keyword)  // Code example for keyword: face_indices face_indices #end  
#if (Keyword = this_keyword)  // Code example for keyword: facets facets #end  
#if (Keyword = this_keyword)  // Code example for keyword: fade_color fade_color #end  
#if (Keyword = this_keyword)  // Code example for keyword: fade_colour fade_colour #end  
#if (Keyword = this_keyword)  // Code example for keyword: fade_distance fade_distance #end  
#if (Keyword = this_keyword)  // Code example for keyword: fade_power fade_power #end  
#if (Keyword = this_keyword)  // Code example for keyword: falloff falloff #end  
#if (Keyword = this_keyword)  // Code example for keyword: falloff_angle falloff_angle #end  
#if (Keyword = this_keyword)  // Code example for keyword: false false #end  
#if (Keyword = this_keyword)  // Code example for keyword: fclose fclose #end  
#if (Keyword = this_keyword)  // Code example for keyword: file_exists file_exists #end  
#if (Keyword = this_keyword)  // Code example for keyword: filter filter #end  
#if (Keyword = this_keyword)  // Code example for keyword: final_clock final_clock #end  
#if (Keyword = this_keyword)  // Code example for keyword: final_frame final_frame #end  
#if (Keyword = this_keyword)  // Code example for keyword: finish finish #end  
#if (Keyword = this_keyword)  // Code example for keyword: fisheye fisheye #end  
#if (Keyword = this_keyword)  // Code example for keyword: flatness flatness #end  
#if (Keyword = this_keyword)  // Code example for keyword: flip flip #end  
#if (Keyword = this_keyword)  // Code example for keyword: floor floor #end  
#if (Keyword = this_keyword)  // Code example for keyword: focal_point focal_point #end  
#if (Keyword = this_keyword)  // Code example for keyword: fog fog #end  
#if (Keyword = this_keyword)  // Code example for keyword: fog_alt fog_alt #end  
#if (Keyword = this_keyword)  // Code example for keyword: fog_offset fog_offset #end  
#if (Keyword = this_keyword)  // Code example for keyword: fog_type fog_type #end  
#if (Keyword = this_keyword)  // Code example for keyword: fopen fopen #end  
#if (Keyword = this_keyword)  // Code example for keyword: for for #end  
#if (Keyword = this_keyword)  // Code example for keyword: form form #end  
#if (Keyword = this_keyword)  // Code example for keyword: frame_number frame_number #end  
#if (Keyword = this_keyword)  // Code example for keyword: frequency frequency #end  
#if (Keyword = this_keyword)  // Code example for keyword: fresnel fresnel #end  
#if (Keyword = this_keyword)  // Code example for keyword: function function #end  

// ################################################# G #################################################

#if (Keyword = this_keyword)  // Code example for keyword: gamma bump maps gamma bump maps #end  
#if (Keyword = this_keyword)  // Code example for keyword: gamma heightfield gamma heightfield #end  
#if (Keyword = this_keyword)  // Code example for keyword: gamma image map gamma image map #end  
#if (Keyword = this_keyword)  // Code example for keyword: gamma image pattern gamma image pattern #end  
#if (Keyword = this_keyword)  // Code example for keyword: gather gather #end  
#if (Keyword = this_keyword)  // Code example for keyword: gif gif #end  
#if (Keyword = this_keyword)  // Code example for keyword: global global #end  
#if (Keyword = this_keyword)  // Code example for keyword: global_lights global_lights #end  
#if (Keyword = this_keyword)  // Code example for keyword: global_settings global_settings #end  
#if (Keyword = this_keyword)  // Code example for keyword: gradient gradient #end  
#if (Keyword = this_keyword)  // Code example for keyword: granite granite #end  
#if (Keyword = this_keyword)  // Code example for keyword: gray gray #end  
#if (Keyword = this_keyword)  // Code example for keyword: gray_threshold gray_threshold #end  
#if (Keyword = this_keyword)  // Code example for keyword: green green #end  

// ################################################# H #################################################

#if (Keyword = this_keyword)  // Code example for keyword: height_field height_field #end  
#if (Keyword = this_keyword)  // Code example for keyword: hexagon hexagon #end  
#if (Keyword = this_keyword)  // Code example for keyword: hf_gray_16 hf_gray_16 #end  
#if (Keyword = this_keyword)  // Code example for keyword: hierarchy hierarchy #end  
#if (Keyword = this_keyword)  // Code example for keyword: hypercomplex hypercomplex #end  
#if (Keyword = this_keyword)  // Code example for keyword: hollow hollow #end  

// ################################################# I #################################################

#if (Keyword = this_keyword)  // Code example for keyword: if if #end  
#if (Keyword = this_keyword)  // Code example for keyword: ifdef ifdef #end  
#if (Keyword = this_keyword)  // Code example for keyword: iff iff #end  
#if (Keyword = this_keyword)  // Code example for keyword: ifndef ifndef #end  
#if (Keyword = this_keyword)  // Code example for keyword: image_height image_height #end  
#if (Keyword = this_keyword)  // Code example for keyword: image_map image_map #end  
#if (Keyword = this_keyword)  // Code example for keyword: image_pattern image_pattern #end  
#if (Keyword = this_keyword)  // Code example for keyword: image_width image_width #end  
#if (Keyword = this_keyword)  // Code example for keyword: importance importance #end  
#if (Keyword = this_keyword)  // Code example for keyword: include include #end  
#if (Keyword = this_keyword)  // Code example for keyword: initial_clock initial_clock #end  
#if (Keyword = this_keyword)  // Code example for keyword: initial_frame initial_frame #end  
#if (Keyword = this_keyword)  // Code example for keyword: input_file_name input_file_name #end  
#if (Keyword = this_keyword)  // Code example for keyword: inside inside #end  
#if (Keyword = this_keyword)  // Code example for keyword: inside_vector inside_vector #end  
#if (Keyword = this_keyword)  // Code example for keyword: int int #end  
#if (Keyword = this_keyword)  // Code example for keyword: interior interior #end  
#if (Keyword = this_keyword)  // Code example for keyword: interior_texture interior_texture #end  
#if (Keyword = this_keyword)  // Code example for keyword: internal internal #end  
#if (Keyword = this_keyword)  // Code example for keyword: interpolate interpolate #end  
#if (Keyword = this_keyword)  // Code example for keyword: intersection csg intersection csg #end  
#if (Keyword = this_keyword)  // Code example for keyword: intersection torus intersection torus #end  
#if (Keyword = this_keyword)  // Code example for keyword: intervals intervals #end  
#if (Keyword = this_keyword)  // Code example for keyword: inverse inverse #end  
#if (Keyword = this_keyword)  // Code example for keyword: ior ior #end  
#if (Keyword = this_keyword)  // Code example for keyword: irid irid #end  
#if (Keyword = this_keyword)  // Code example for keyword: irid_wavelength irid_wavelength #end  
#if (Keyword = this_keyword)  // Code example for keyword: isosurface isosurface #end  

// ################################################# J #################################################

#if (Keyword = this_keyword)  // Code example for keyword: jitter jitter #end  
#if (Keyword = this_keyword)  // Code example for keyword: jpeg jpeg #end  
#if (Keyword = this_keyword)  // Code example for keyword: julia julia #end  
#if (Keyword = this_keyword)  // Code example for keyword: julia_fractal julia_fractal #end  

// ################################################# K #################################################

// ################################################# L #################################################

#if (Keyword = this_keyword)  // Code example for keyword: lambda lambda #end  
#if (Keyword = this_keyword)  // Code example for keyword: lathe lathe #end  
#if (Keyword = this_keyword)  // Code example for keyword: lemon lemon #end  
#if (Keyword = this_keyword)  // Code example for keyword: leopard leopard #end  
#if (Keyword = this_keyword)  // Code example for keyword: light_group light_group #end  
#if (Keyword = this_keyword)  // Code example for keyword: light_source light_source #end  
#if (Keyword = this_keyword)  // Code example for keyword: linear_spline linear_spline #end  
#if (Keyword = this_keyword)  // Code example for keyword: linear_sweep linear_sweep #end  
#if (Keyword = this_keyword)  // Code example for keyword: ln ln #end  
#if (Keyword = this_keyword)  // Code example for keyword: load_file load_file #end  
#if (Keyword = this_keyword)  // Code example for keyword: local directive local directive #end  
#if (Keyword = this_keyword)  // Code example for keyword: local dictionary local dictionary #end  
#if (Keyword = this_keyword)  // Code example for keyword: location location #end  
#if (Keyword = this_keyword)  // Code example for keyword: log log #end  
#if (Keyword = this_keyword)  // Code example for keyword: look_at look_at #end  
#if (Keyword = this_keyword)  // Code example for keyword: looks_like looks_like #end  
#if (Keyword = this_keyword)  // Code example for keyword: low_error_factor low_error_factor #end  

// ################################################# M #################################################

#if (Keyword = this_keyword)  // Code example for keyword: macro macro #end  
#if (Keyword = this_keyword)  // Code example for keyword: magnet magnet #end  
#if (Keyword = this_keyword)  // Code example for keyword: major_radius major_radius #end  
#if (Keyword = this_keyword)  // Code example for keyword: mandel mandel #end  
#if (Keyword = this_keyword)  // Code example for keyword: map_type map_type #end  
#if (Keyword = this_keyword)  // Code example for keyword: marble marble #end  
#if (Keyword = this_keyword)  // Code example for keyword: material material #end  
#if (Keyword = this_keyword)  // Code example for keyword: material_map material_map #end  
#if (Keyword = this_keyword)  // Code example for keyword: matrix matrix #end  
#if (Keyword = this_keyword)  // Code example for keyword: max max #end  
#if (Keyword = this_keyword)  // Code example for keyword: maximum_reuse maximum_reuse #end  
#if (Keyword = this_keyword)  // Code example for keyword: max_extent max_extent #end  
#if (Keyword = this_keyword)  // Code example for keyword: max_gradient max_gradient #end  
#if (Keyword = this_keyword)  // Code example for keyword: max_intersections max_intersections #end  
#if (Keyword = this_keyword)  // Code example for keyword: max_iteration max_iteration #end  
#if (Keyword = this_keyword)  // Code example for keyword: max_sample max_sample #end  
#if (Keyword = this_keyword)  // Code example for keyword: max_trace max_trace #end  
#if (Keyword = this_keyword)  // Code example for keyword: max_trace_level max_trace_level #end  
#if (Keyword = this_keyword)  // Code example for keyword: media media #end  
#if (Keyword = this_keyword)  // Code example for keyword: media_attenuation media_attenuation #end  
#if (Keyword = this_keyword)  // Code example for keyword: media_interaction media_interaction #end  
#if (Keyword = this_keyword)  // Code example for keyword: merge csg merge csg #end  
#if (Keyword = this_keyword)  // Code example for keyword: merge torus merge torus #end  
#if (Keyword = this_keyword)  // Code example for keyword: mesh mesh #end  
#if (Keyword = this_keyword)  // Code example for keyword: mesh2 mesh2 #end  
#if (Keyword = this_keyword)  // Code example for keyword: metallic metallic #end  
#if (Keyword = this_keyword)  // Code example for keyword: method method #end  
#if (Keyword = this_keyword)  // Code example for keyword: metric metric #end  
#if (Keyword = this_keyword)  // Code example for keyword: min min #end  
#if (Keyword = this_keyword)  // Code example for keyword: min_extent min_extent #end  
#if (Keyword = this_keyword)  // Code example for keyword: minimum_reuse minimum_reuse #end  
#if (Keyword = this_keyword)  // Code example for keyword: mixed mixed #end  
#if (Keyword = this_keyword)  // Code example for keyword: mm_per_unit mm_per_unit #end  
#if (Keyword = this_keyword)  // Code example for keyword: mod mod #end  
#if (Keyword = this_keyword)  // Code example for keyword: mortar mortar #end  

// ################################################# N #################################################

#if (Keyword = this_keyword)  // Code example for keyword: natural_spline natural_spline #end  
#if (Keyword = this_keyword)  // Code example for keyword: nearest_count nearest_count #end  
#if (Keyword = this_keyword)  // Code example for keyword: no no #end  
#if (Keyword = this_keyword)  // Code example for keyword: no_bump_scale no_bump_scale #end  
#if (Keyword = this_keyword)  // Code example for keyword: no_image no_image #end  
#if (Keyword = this_keyword)  // Code example for keyword: no_radiosity no_radiosity #end  
#if (Keyword = this_keyword)  // Code example for keyword: no_reflection no_reflection #end  
#if (Keyword = this_keyword)  // Code example for keyword: no_shadow no_shadow #end  
#if (Keyword = this_keyword)  // Code example for keyword: noise_generator noise_generator #end  
#if (Keyword = this_keyword)  // Code example for keyword: normal normal #end  
#if (Keyword = this_keyword)  // Code example for keyword: normal_indices normal_indices #end  
#if (Keyword = this_keyword)  // Code example for keyword: normal_map normal_map #end  
#if (Keyword = this_keyword)  // Code example for keyword: normal_vectors normal_vectors #end  
#if (Keyword = this_keyword)  // Code example for keyword: now now #end  
#if (Keyword = this_keyword)  // Code example for keyword: number_of_waves number_of_waves #end  

// ################################################# O #################################################

#if (Keyword = this_keyword)  // Code example for keyword: object object #end  
#if (Keyword = this_keyword)  // Code example for keyword: octaves octaves #end  
#if (Keyword = this_keyword)  // Code example for keyword: off off #end  
#if (Keyword = this_keyword)  // Code example for keyword: offset offset #end  
#if (Keyword = this_keyword)  // Code example for keyword: omega omega #end  
#if (Keyword = this_keyword)  // Code example for keyword: omnimax omnimax #end  
#if (Keyword = this_keyword)  // Code example for keyword: on on #end  
#if (Keyword = this_keyword)  // Code example for keyword: once once #end  
#if (Keyword = this_keyword)  // Code example for keyword: onion onion #end  
#if (Keyword = this_keyword)  // Code example for keyword: open open #end  
#if (Keyword = this_keyword)  // Code example for keyword: optional optional #end  
#if (Keyword = this_keyword)  // Code example for keyword: orient orient #end  
#if (Keyword = this_keyword)  // Code example for keyword: orientation orientation #end  
#if (Keyword = this_keyword)  // Code example for keyword: orthographic orthographic #end  
#if (Keyword = this_keyword)  // Code example for keyword: ovus ovus #end  

// ################################################# P #################################################

#if (Keyword = this_keyword)  // Code example for keyword: panoramic panoramic #end  
#if (Keyword = this_keyword)  // Code example for keyword: parallel parallel #end  
#if (Keyword = this_keyword)  // Code example for keyword: parametric parametric #end  
#if (Keyword = this_keyword)  // Code example for keyword: pass_through pass_through #end  
#if (Keyword = this_keyword)  // Code example for keyword: pattern pattern #end  
#if (Keyword = this_keyword)  // Code example for keyword: pavement pavement #end  
#if (Keyword = this_keyword)  // Code example for keyword: perspective perspective #end  
#if (Keyword = this_keyword)  // Code example for keyword: pgm pgm #end  
#if (Keyword = this_keyword)  // Code example for keyword: phase phase #end  
#if (Keyword = this_keyword)  // Code example for keyword: phong phong #end  
#if (Keyword = this_keyword)  // Code example for keyword: phong_size phong_size #end  
#if (Keyword = this_keyword)  // Code example for keyword: photons photons #end  
#if (Keyword = this_keyword)  // Code example for keyword: pi pi #end  
#if (Keyword = this_keyword)  // Code example for keyword: pigment pigment #end  
#if (Keyword = this_keyword)  // Code example for keyword: pigment_map pigment_map #end  
#if (Keyword = this_keyword)  // Code example for keyword: pigment_pattern pigment_pattern #end  
#if (Keyword = this_keyword)  // Code example for keyword: planar planar #end  
#if (Keyword = this_keyword)  // Code example for keyword: plane plane #end  
#if (Keyword = this_keyword)  // Code example for keyword: png png #end  
#if (Keyword = this_keyword)  // Code example for keyword: point_at point_at #end  
#if (Keyword = this_keyword)  // Code example for keyword: polarity polarity #end  
#if (Keyword = this_keyword)  // Code example for keyword: poly poly #end  
#if (Keyword = this_keyword)  // Code example for keyword: polynomial polynomial #end  
#if (Keyword = this_keyword)  // Code example for keyword: poly_wave poly_wave #end  
#if (Keyword = this_keyword)  // Code example for keyword: polygon polygon #end  
#if (Keyword = this_keyword)  // Code example for keyword: pot pot #end  
#if (Keyword = this_keyword)  // Code example for keyword: potential potential #end  
#if (Keyword = this_keyword)  // Code example for keyword: pow pow #end  
#if (Keyword = this_keyword)  // Code example for keyword: ppm ppm #end  
#if (Keyword = this_keyword)  // Code example for keyword: precision julia precision julia #end  
#if (Keyword = this_keyword)  // Code example for keyword: precision ovus precision ovus #end  
#if (Keyword = this_keyword)  // Code example for keyword: precompute precompute #end  
#if (Keyword = this_keyword)  // Code example for keyword: premultiplied premultiplied #end  
#if (Keyword = this_keyword)  // Code example for keyword: pretrace_end pretrace_end #end  
#if (Keyword = this_keyword)  // Code example for keyword: pretrace_start pretrace_start #end  
#if (Keyword = this_keyword)  // Code example for keyword: prism prism #end  
#if (Keyword = this_keyword)  // Code example for keyword: prod prod #end  
#if (Keyword = this_keyword)  // Code example for keyword: projected_through projected_through #end  
#if (Keyword = this_keyword)  // Code example for keyword: pwr pwr #end  

// ################################################# Q #################################################

#if (Keyword = this_keyword)  // Code example for keyword: quadratic_spline quadratic_spline #end  
#if (Keyword = this_keyword)  // Code example for keyword: quadric quadric #end  
#if (Keyword = this_keyword)  // Code example for keyword: quartic quartic #end  
#if (Keyword = this_keyword)  // Code example for keyword: quaternion quaternion #end  
#if (Keyword = this_keyword)  // Code example for keyword: quick_color quick_color #end  
#if (Keyword = this_keyword)  // Code example for keyword: quick_colour quick_colour #end  
#if (Keyword = this_keyword)  // Code example for keyword: quilted quilted #end  

// ################################################# R #################################################

#if (Keyword = this_keyword)  // Code example for keyword: radial radial #end  
#if (Keyword = this_keyword)  // Code example for keyword: radians radians #end  
#if (Keyword = this_keyword)  // Code example for keyword: radiosity radiosity #end  
#if (Keyword = this_keyword)  // Code example for keyword: radius spotlight radius spotlight #end  
#if (Keyword = this_keyword)  // Code example for keyword: radius ovus radius ovus #end  
#if (Keyword = this_keyword)  // Code example for keyword: rainbow rainbow #end  
#if (Keyword = this_keyword)  // Code example for keyword: ramp_wave ramp_wave #end  
#if (Keyword = this_keyword)  // Code example for keyword: rand rand #end  
#if (Keyword = this_keyword)  // Code example for keyword: range range #end  
#if (Keyword = this_keyword)  // Code example for keyword: ratio ratio #end  
#if (Keyword = this_keyword)  // Code example for keyword: read read #end  
#if (Keyword = this_keyword)  // Code example for keyword: reciprocal reciprocal #end  
#if (Keyword = this_keyword)  // Code example for keyword: recursion_limit recursion_limit #end  
#if (Keyword = this_keyword)  // Code example for keyword: red red #end  
#if (Keyword = this_keyword)  // Code example for keyword: reflection reflection #end  
#if (Keyword = this_keyword)  // Code example for keyword: reflection_exponent reflection_exponent #end  
#if (Keyword = this_keyword)  // Code example for keyword: refraction refraction #end  
#if (Keyword = this_keyword)  // Code example for keyword: render render #end  
#if (Keyword = this_keyword)  // Code example for keyword: repeat crackle pattern repeat crackle pattern #end  
#if (Keyword = this_keyword)  // Code example for keyword: repeat warp repeat warp #end  
#if (Keyword = this_keyword)  // Code example for keyword: rgb rgb #end  
#if (Keyword = this_keyword)  // Code example for keyword: rgbf rgbf #end  
#if (Keyword = this_keyword)  // Code example for keyword: rgbft rgbft #end  
#if (Keyword = this_keyword)  // Code example for keyword: rgbt rgbt #end  
#if (Keyword = this_keyword)  // Code example for keyword: right right #end  
#if (Keyword = this_keyword)  // Code example for keyword: ripples ripples #end  
#if (Keyword = this_keyword)  // Code example for keyword: rotate rotate #end  
#if (Keyword = this_keyword)  // Code example for keyword: roughness roughness #end  

// ################################################# S #################################################

#if (Keyword = this_keyword)  // Code example for keyword: samples media samples media #end  
#if (Keyword = this_keyword)  // Code example for keyword: samples subsurface samples subsurface #end  
#if (Keyword = this_keyword)  // Code example for keyword: save_file save_file #end  
#if (Keyword = this_keyword)  // Code example for keyword: scale scale #end  
#if (Keyword = this_keyword)  // Code example for keyword: scallop_wave scallop_wave #end  
#if (Keyword = this_keyword)  // Code example for keyword: scattering scattering #end  
#if (Keyword = this_keyword)  // Code example for keyword: seed seed #end  
#if (Keyword = this_keyword)  // Code example for keyword: select select #end  
#if (Keyword = this_keyword)  // Code example for keyword: shadowless shadowless #end  
#if (Keyword = this_keyword)  // Code example for keyword: sin sin #end  
#if (Keyword = this_keyword)  // Code example for keyword: sine_wave sine_wave #end  
#if (Keyword = this_keyword)  // Code example for keyword: sinh sinh #end  
#if (Keyword = this_keyword)  // Code example for keyword: sint8 sint8 #end  
#if (Keyword = this_keyword)  // Code example for keyword: sint16be sint16be #end  
#if (Keyword = this_keyword)  // Code example for keyword: sint16le sint16le #end  
#if (Keyword = this_keyword)  // Code example for keyword: sint32be sint32be #end  
#if (Keyword = this_keyword)  // Code example for keyword: sint32le sint32le #end  
#if (Keyword = this_keyword)  // Code example for keyword: size size #end  
#if (Keyword = this_keyword)  // Code example for keyword: sky sky #end  
#if (Keyword = this_keyword)  // Code example for keyword: sky_sphere sky_sphere #end  
#if (Keyword = this_keyword)  // Code example for keyword: slice slice #end  
#if (Keyword = this_keyword)  // Code example for keyword: slope slope #end  
#if (Keyword = this_keyword)  // Code example for keyword: slope_map slope_map #end  
#if (Keyword = this_keyword)  // Code example for keyword: smooth smooth #end  
#if (Keyword = this_keyword)  // Code example for keyword: smooth_triangle smooth_triangle #end  
#if (Keyword = this_keyword)  // Code example for keyword: solid solid #end  
#if (Keyword = this_keyword)  // Code example for keyword: sor sor #end  
#if (Keyword = this_keyword)  // Code example for keyword: spacing spacing #end  
#if (Keyword = this_keyword)  // Code example for keyword: specular specular #end  
#if (Keyword = this_keyword)  // Code example for keyword: sphere sphere #end  
#if (Keyword = this_keyword)  // Code example for keyword: sphere_sweep sphere_sweep #end  
#if (Keyword = this_keyword)  // Code example for keyword: spherical spherical #end  
#if (Keyword = this_keyword)  // Code example for keyword: spiral1 spiral1 #end  
#if (Keyword = this_keyword)  // Code example for keyword: spiral2 spiral2 #end  
#if (Keyword = this_keyword)  // Code example for keyword: spline spline #end  
#if (Keyword = this_keyword)  // Code example for keyword: split_union split_union #end  
#if (Keyword = this_keyword)  // Code example for keyword: spotlight spotlight #end  
#if (Keyword = this_keyword)  // Code example for keyword: spotted spotted #end  
#if (Keyword = this_keyword)  // Code example for keyword: sqr sqr #end  
#if (Keyword = this_keyword)  // Code example for keyword: sqrt sqrt #end  
#if (Keyword = this_keyword)  // Code example for keyword: square square #end  
#if (Keyword = this_keyword)  // Code example for keyword: srgb bump maps srgb bump maps #end  
#if (Keyword = this_keyword)  // Code example for keyword: srgb color literals srgb color literals #end  
#if (Keyword = this_keyword)  // Code example for keyword: srgb heightfield srgb heightfield #end  
#if (Keyword = this_keyword)  // Code example for keyword: srgb image maps srgb image maps #end  
#if (Keyword = this_keyword)  // Code example for keyword: srgb image pattern srgb image pattern #end  
#if (Keyword = this_keyword)  // Code example for keyword: srgbf srgbf #end  
#if (Keyword = this_keyword)  // Code example for keyword: srgbt srgbt #end  
#if (Keyword = this_keyword)  // Code example for keyword: srgbft srgbft #end  
#if (Keyword = this_keyword)  // Code example for keyword: statistics statistics #end  
#if (Keyword = this_keyword)  // Code example for keyword: str str #end  
#if (Keyword = this_keyword)  // Code example for keyword: strcmp strcmp #end  
#if (Keyword = this_keyword)  // Code example for keyword: strength strength #end  
#if (Keyword = this_keyword)  // Code example for keyword: strlen strlen #end  
#if (Keyword = this_keyword)  // Code example for keyword: strlwr strlwr #end  
#if (Keyword = this_keyword)  // Code example for keyword: strupr strupr #end  
#if (Keyword = this_keyword)  // Code example for keyword: sturm sturm #end  
#if (Keyword = this_keyword)  // Code example for keyword: substr substr #end  
#if (Keyword = this_keyword)  // Code example for keyword: subsurface subsurface #end  
#if (Keyword = this_keyword)  // Code example for keyword: sum sum #end  
#if (Keyword = this_keyword)  // Code example for keyword: superellipsoid superellipsoid #end  
#if (Keyword = this_keyword)  // Code example for keyword: switch switch #end  
#if (Keyword = this_keyword)  // Code example for keyword: sys sys #end  

// ################################################# T #################################################

#if (Keyword = this_keyword)  // Code example for keyword: t t #end  
#if (Keyword = this_keyword)  // Code example for keyword: tan tan #end  
#if (Keyword = this_keyword)  // Code example for keyword: tanh tanh #end  
#if (Keyword = this_keyword)  // Code example for keyword: target target #end  
#if (Keyword = this_keyword)  // Code example for keyword: tau tau #end  
#if (Keyword = this_keyword)  // Code example for keyword: text text #end  
#if (Keyword = this_keyword)  // Code example for keyword: texture texture #end  
#if (Keyword = this_keyword)  // Code example for keyword: texture_list texture_list #end  
#if (Keyword = this_keyword)  // Code example for keyword: texture_map texture_map #end  
#if (Keyword = this_keyword)  // Code example for keyword: tga tga #end  
#if (Keyword = this_keyword)  // Code example for keyword: thickness thickness #end  
#if (Keyword = this_keyword)  // Code example for keyword: threshold blob threshold blob #end  
#if (Keyword = this_keyword)  // Code example for keyword: threshold isosurface threshold isosurface #end  
#if (Keyword = this_keyword)  // Code example for keyword: threshold potential pattern threshold potential pattern #end  
#if (Keyword = this_keyword)  // Code example for keyword: tiff tiff #end  
#if (Keyword = this_keyword)  // Code example for keyword: tightness tightness #end  
#if (Keyword = this_keyword)  // Code example for keyword: tile2 tile2 #end  
#if (Keyword = this_keyword)  // Code example for keyword: tiles tiles #end  
#if (Keyword = this_keyword)  // Code example for keyword: tiling tiling #end  
#if (Keyword = this_keyword)  // Code example for keyword: tolerance tolerance #end  
#if (Keyword = this_keyword)  // Code example for keyword: toroidal toroidal #end  
#if (Keyword = this_keyword)  // Code example for keyword: torus torus #end  
#if (Keyword = this_keyword)  // Code example for keyword: trace trace #end  
#if (Keyword = this_keyword)  // Code example for keyword: transform transform #end  
#if (Keyword = this_keyword)  // Code example for keyword: translate translate #end  
#if (Keyword = this_keyword)  // Code example for keyword: translucency translucency #end  
#if (Keyword = this_keyword)  // Code example for keyword: transmit transmit #end  
#if (Keyword = this_keyword)  // Code example for keyword: triangle triangle #end  
#if (Keyword = this_keyword)  // Code example for keyword: triangle_wave triangle_wave #end  
#if (Keyword = this_keyword)  // Code example for keyword: triangular triangular #end  
#if (Keyword = this_keyword)  // Code example for keyword: true true #end  
#if (Keyword = this_keyword)  // Code example for keyword: ttf ttf #end  
#if (Keyword = this_keyword)  // Code example for keyword: turb_depth turb_depth #end  
#if (Keyword = this_keyword)  // Code example for keyword: turbulence turbulence #end  
#if (Keyword = this_keyword)  // Code example for keyword: type type #end  

// ################################################# U #################################################

#if (Keyword = this_keyword)  // Code example for keyword: u u #end  
#if (Keyword = this_keyword)  // Code example for keyword: uint8 uint8 #end  
#if (Keyword = this_keyword)  // Code example for keyword: uint16be uint16be #end  
#if (Keyword = this_keyword)  // Code example for keyword: uint16le uint16le #end  
#if (Keyword = this_keyword)  // Code example for keyword: u_steps u_steps #end  
#if (Keyword = this_keyword)  // Code example for keyword: ultra_wide_angle ultra_wide_angle #end  
#if (Keyword = this_keyword)  // Code example for keyword: undef undef #end  
#if (Keyword = this_keyword)  // Code example for keyword: union csg union csg #end  
#if (Keyword = this_keyword)  // Code example for keyword: union torus union torus #end  
#if (Keyword = this_keyword)  // Code example for keyword: up up #end  
#if (Keyword = this_keyword)  // Code example for keyword: use_alpha image pattern use_alpha image pattern #end  
#if (Keyword = this_keyword)  // Code example for keyword: use_alpha finish use_alpha finish #end  
#if (Keyword = this_keyword)  // Code example for keyword: use_color use_color #end  
#if (Keyword = this_keyword)  // Code example for keyword: use_colour use_colour #end  
#if (Keyword = this_keyword)  // Code example for keyword: use_index use_index #end  
#if (Keyword = this_keyword)  // Code example for keyword: user_defined projection user_defined projection #end  
#if (Keyword = this_keyword)  // Code example for keyword: user_defined pattern user_defined pattern #end  
#if (Keyword = this_keyword)  // Code example for keyword: utf8 utf8 #end  
#if (Keyword = this_keyword)  // Code example for keyword: uv_indices uv_indices #end  
#if (Keyword = this_keyword)  // Code example for keyword: uv_mapping uv_mapping #end  
#if (Keyword = this_keyword)  // Code example for keyword: uv_vectors uv_vectors #end  

// ################################################# V #################################################

#if (Keyword = this_keyword)  // Code example for keyword: v v #end  
#if (Keyword = this_keyword)  // Code example for keyword: v_steps v_steps #end  
#if (Keyword = this_keyword)  // Code example for keyword: val val #end  
#if (Keyword = this_keyword)  // Code example for keyword: variance variance #end  
#if (Keyword = this_keyword)  // Code example for keyword: vaxis_rotate vaxis_rotate #end  
#if (Keyword = this_keyword)  // Code example for keyword: vcross vcross #end  
#if (Keyword = this_keyword)  // Code example for keyword: vdot vdot #end  
#if (Keyword = this_keyword)  // Code example for keyword: version version #end  
#if (Keyword = this_keyword)  // Code example for keyword: vertex_vectors vertex_vectors #end  
#if (Keyword = this_keyword)  // Code example for keyword: vlength vlength #end  
#if (Keyword = this_keyword)  // Code example for keyword: vnormalize vnormalize #end  
#if (Keyword = this_keyword)  // Code example for keyword: vrotate vrotate #end  
#if (Keyword = this_keyword)  // Code example for keyword: vstr vstr #end  
#if (Keyword = this_keyword)  // Code example for keyword: vturbulence vturbulence #end  

// ################################################# W #################################################

#if (Keyword = this_keyword)  // Code example for keyword: warning warning #end  
#if (Keyword = this_keyword)  // Code example for keyword: warp warp #end  
#if (Keyword = this_keyword)  // Code example for keyword: water_level water_level #end  
#if (Keyword = this_keyword)  // Code example for keyword: waves waves #end  
#if (Keyword = this_keyword)  // Code example for keyword: while while #end  
#if (Keyword = this_keyword)  // Code example for keyword: width width #end  
#if (Keyword = this_keyword)  // Code example for keyword: wood wood #end  
#if (Keyword = this_keyword)  // Code example for keyword: wrinkles wrinkles #end  
#if (Keyword = this_keyword)  // Code example for keyword: write write #end  

// ################################################# X #################################################

#if (Keyword = this_keyword)  // Code example for keyword: x x #end  

// ################################################# Y #################################################

#if (Keyword = this_keyword)  // Code example for keyword: y y #end  
#if (Keyword = this_keyword)  // Code example for keyword: yes yes #end  

// ################################################# Z #################################################

#if (Keyword = this_keyword)  // Code example for keyword: z z #end 

*/